# Factcheck

Types:

```python
from bespokelabs.types import FactcheckCreateResponse
```

Methods:

- <code title="post /v0/factcheck">client.factcheck.<a href="./src/bespokelabs/resources/factcheck.py">create</a>(\*\*<a href="src/bespokelabs/types/factcheck_create_params.py">params</a>) -> <a href="./src/bespokelabs/types/factcheck_create_response.py">FactcheckCreateResponse</a></code>
